==> react-intl-hooks-1.0.4.tgz: package/CHANGELOG.md <==
# 1.0.4 (May 29, 2020)

v1.0.4 is a maintenance release includes updates to dependencies and a bugfix related to the `preinstall` script.

#### :bug: Bug Fix
- #11 Removed preinstall script from package.json. ([@MateoKruk ](https://github.com/MateoKruk))

#### :hammer: Underlying tools
- #12 update `@babel/core` to 7.10.1. ([@MateoKruk ](https://github.com/MateoKruk))
- #9  update `@babel/preset-env` to 7.10.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #8 update `@babel/preset-react` to 7.10.0. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.3 to 1.0.4

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.4
```

or

```
yarn add --exact react-intl-hooks@1.0.4
```

# 1.0.3 (May 25, 2020)

v1.0.3 is a maintenance release that updates dependencies.

#### :hammer: Underlying tools
- #3 update `@types/node` to 14.0.5. ([@MateoKruk ](https://github.com/MateoKruk))
- #4  update `typescript` to 3.9.3. ([@MateoKruk ](https://github.com/MateoKruk))
- #5 update `rollup` to 2.10.9. ([@MateoKruk ](https://github.com/MateoKruk))
- #6 update `@rollup/plugin-commonjs` to 12.0.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #7 update `react-intl` to 4.5.12. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.2 to 1.0.3

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.3
```

or

```
yarn add --exact react-intl-hooks@1.0.3
```

# 1.0.2 (May 22, 2020)

v1.0.2 is a maintenance release that updates dependencies.

#### :hammer: Underlying tools
- #1 update `react-intl` to  4.5.8. ([@MateoKruk ](https://github.com/MateoKruk))
- #2 update `lint-staged` to 10.2.6. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.1 to 1.0.2

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.2
```

or

```
yarn add --exact react-intl-hooks@1.0.2
```

# 1.0.1 (May 20, 2020)

v1.0.1 is a maintenance release that includes documentation updates.

#### :memo: Documentation

- Fix typo documentation. ([@tpiaggio ](https://github.com/tpiaggio))
- Better examples on how to import and use each hook. ([@MateoKruk ](https://github.com/MateoKruk))
- Fixed bundlephobia badge not showing up. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.0 to 1.0.1

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.1
```

or

```
yarn add --exact react-intl-hooks@1.0.1
```

# 1.0.0 (May 19, 2020)

v1.0.0 is the initial release of the library 👨‍💻. 

### Installing 1.0.0

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.0
```

or

```
yarn add --exact react-intl-hooks@1.0.0
```

==> react-intl-hooks-1.0.5.tgz: package/CHANGELOG.md <==
# 1.0.5 (June 5, 2020)

v1.0.5 is a maintenance release includes updates to dependencies.

#### :hammer: Underlying tools

- #21 update `react-intl` to 4.6.6. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `@rollup/plugin-commonjs` to 13.0.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `@typescript-eslint/eslint-plugin` to 3.1.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `@typescript-eslint/parser` to 3.1.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `eslint` to 7.1.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `eslint-plugin-react-hooks` to 4.0.4. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `jest` to 26.0.1. ([@MateoKruk ](https://github.com/MateoKruk))
- #21 update `ts-jest` to 26.1.0. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.4 to 1.0.5

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.5
```

or

```
yarn add --exact react-intl-hooks@1.0.5
```

# 1.0.4 (May 29, 2020)

v1.0.4 is a maintenance release that includes updates to dependencies and a bugfix related to the `preinstall` script.

#### :bug: Bug Fix

- #11 Removed preinstall script from package.json. ([@MateoKruk ](https://github.com/MateoKruk))

#### :hammer: Underlying tools

- #12 update `@babel/core` to 7.10.1. ([@MateoKruk ](https://github.com/MateoKruk))
- #9 update `@babel/preset-env` to 7.10.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #8 update `@babel/preset-react` to 7.10.0. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.3 to 1.0.4

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.4
```

or

```
yarn add --exact react-intl-hooks@1.0.4
```

# 1.0.3 (May 25, 2020)

v1.0.3 is a maintenance release that updates dependencies.

#### :hammer: Underlying tools

- #3 update `@types/node` to 14.0.5. ([@MateoKruk ](https://github.com/MateoKruk))
- #4 update `typescript` to 3.9.3. ([@MateoKruk ](https://github.com/MateoKruk))
- #5 update `rollup` to 2.10.9. ([@MateoKruk ](https://github.com/MateoKruk))
- #6 update `@rollup/plugin-commonjs` to 12.0.0. ([@MateoKruk ](https://github.com/MateoKruk))
- #7 update `react-intl` to 4.5.12. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.2 to 1.0.3

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.3
```

or

```
yarn add --exact react-intl-hooks@1.0.3
```

# 1.0.2 (May 22, 2020)

v1.0.2 is a maintenance release that updates dependencies.

#### :hammer: Underlying tools

- #1 update `react-intl` to 4.5.8. ([@MateoKruk ](https://github.com/MateoKruk))
- #2 update `lint-staged` to 10.2.6. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.1 to 1.0.2

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.2
```

or

```
yarn add --exact react-intl-hooks@1.0.2
```

# 1.0.1 (May 20, 2020)

v1.0.1 is a maintenance release that includes documentation updates.

#### :memo: Documentation

- Fix typo documentation. ([@tpiaggio ](https://github.com/tpiaggio))
- Better examples on how to import and use each hook. ([@MateoKruk ](https://github.com/MateoKruk))
- Fixed bundlephobia badge not showing up. ([@MateoKruk ](https://github.com/MateoKruk))

### Migrating from 1.0.0 to 1.0.1

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.1
```

or

```
yarn add --exact react-intl-hooks@1.0.1
```

# 1.0.0 (May 19, 2020)

v1.0.0 is the initial release of the library 👨‍💻.

### Installing 1.0.0

Inside your project, run:

```
npm install --save --save-exact react-intl-hooks@1.0.0
```

or

```
yarn add --exact react-intl-hooks@1.0.0
```
